@@ -24,8 +24,13 @@ assembly. The basic workflow of assembly is the following:
 
 >>> A = asm(form_a, basis)
 >>> b = asm(form_l, basis)
+>>> A
+<4x4 sparse matrix of type '<class 'numpy.float64'>'
+       with 14 stored elements in Compressed Sparse Row format>
+>>> b
+array([0.0162037 , 0.15046296, 0.06712963, 0.09953704])
 
-The above steps assemble the matrix corresponding
+The above example assembles the matrix corresponding
 to the bilinear form
 
 .. math::
@@ -38,7 +43,7 @@ and the vector corresponding to the linear form
 
     l(v) = \int_0^1 \int_0^1 x^2v(x,y) \,\mathrm{d}x \,\mathrm{d}y
 
-using piecewise linear basis functions.
+using piecewise-linear basis functions.
 
 """
 
@@ -49,9 +54,8 @@ from numpy import ndarray
 from scipy.sparse import csr_matrix
 
 from .basis import Basis, InteriorBasis, FacetBasis
-from .dofs import Dofs
-from .form import Form, BilinearForm, LinearForm, Functional,\
-    bilinear_form, linear_form, functional
+from .dofs import Dofs, DofsView
+from .form import Form, BilinearForm, LinearForm, Functional
 
 
 def asm(form: Form,
@@ -70,9 +74,7 @@ __all__ = [
     "InteriorBasis",
     "FacetBasis",
     "Dofs",
+    "DofsView",
     "BilinearForm",
     "LinearForm",
-    "Functional",
-    "bilinear_form",
-    "linear_form",
-    "functional"]
+    "Functional"]
