@@ -19,6 +19,7 @@ class ElementComposite(Element):
         self.facet_dofs = sum([e.facet_dofs for e in self.elems])
         self.interior_dofs = sum([e.interior_dofs for e in self.elems])
         self.maxdeg = sum([e.maxdeg for e in self.elems])
+        self.dim = self.elems[0].dim
 
         for e in self.elems:
             if e.mesh_type is not self.elems[0].mesh_type:
@@ -82,13 +83,13 @@ class ElementComposite(Element):
 
         return ns[i], inds[i]
 
-    def gbasis(self, mapping, X: ndarray, i: int, **kwargs):
+    def gbasis(self, mapping, X: ndarray, i: int, tind=None):
         n, ind = self._deduce_bfun(i)
         output = []
         for k, e in enumerate(self.elems):
             if n == k:
-                output.append(e.gbasis(mapping, X, ind, **kwargs)[0])
+                output.append(e.gbasis(mapping, X, ind, tind)[0])
             else:
-                output.append(e.gbasis(mapping, X, 0, **kwargs)[0]
+                output.append(e.gbasis(mapping, X, 0, tind)[0]
                               .zeros_like())
         return tuple(output)
