@@ -1,7 +1,8 @@
 # -*- coding: utf-8 -*-
-"""This module defines different types of finite element meshes.  Meshes can be
-created using various built-in constructors or loaded from external formats
-using `meshio <https://github.com/nschloe/meshio>`_.  The supported types are
+"""This module defines different types of finite element meshes.  Meshes can
+be created using various built-in constructors or loaded from external
+formats using `meshio <https://github.com/nschloe/meshio>`_.  The supported
+types are
 
 - :class:`~skfem.mesh.MeshTri`, triangular mesh
 - :class:`~skfem.mesh.MeshQuad`, quadrilateral mesh
@@ -36,3 +37,15 @@ from .mesh import Mesh, MeshType
 from .mesh_line import MeshLine
 from .mesh2d import Mesh2D, MeshTri, MeshQuad
 from .mesh3d import Mesh3D, MeshTet, MeshHex
+
+
+__all__ = [
+    "Mesh",
+    "MeshType",
+    "MeshLine",
+    "Mesh2D",
+    "MeshTri",
+    "MeshQuad",
+    "Mesh3D",
+    "MeshTet",
+    "MeshHex"]
