@@ -2,8 +2,8 @@
 SciPy linear solvers."""
 
 import warnings
-from typing import Optional, Union, Tuple,\
-    Callable, Dict
+from typing import Optional, Union, Tuple, Callable, Dict
+from inspect import signature
 
 import numpy as np
 import scipy.sparse as sp
@@ -12,7 +12,7 @@ import scipy.sparse.linalg as spl
 from numpy import ndarray
 from scipy.sparse import spmatrix
 
-from skfem.assembly import asm, BilinearForm, LinearForm, Dofs
+from skfem.assembly import asm, BilinearForm, LinearForm, DofsView
 from skfem.assembly.basis import Basis
 from skfem.element import ElementVectorH1
 
@@ -28,7 +28,7 @@ CondensedSystem = Union[spmatrix,
                         Tuple[spmatrix, ndarray, ndarray],
                         Tuple[spmatrix, ndarray, ndarray, ndarray],
                         Tuple[spmatrix, spmatrix, ndarray, ndarray]]
-DofsCollection = Union[ndarray, Dofs, Dict[str, Dofs]]
+DofsCollection = Union[ndarray, DofsView, Dict[str, DofsView]]
 
 
 # preconditioners, e.g. for :func:`skfem.utils.solver_iter_krylov`
@@ -76,6 +76,7 @@ def solver_eigen_scipy(**kwargs) -> EigenSolver:
 
 
 def solver_direct_scipy(**kwargs) -> LinearSolver:
+    """The default linear solver of SciPy."""
     def solver(A, b, **solve_time_kwargs):
         kwargs.update(solve_time_kwargs)
         return spl.spsolve(A, b, **kwargs)
@@ -185,11 +186,11 @@ def _flatten_dofs(S: DofsCollection) -> ndarray:
     else:
         if isinstance(S, ndarray):
             return S
-        elif isinstance(S, Dofs):
-            return S.all()
+        elif isinstance(S, DofsView):
+            return S.flatten()
         elif isinstance(S, dict):
-            return np.unique(np.concatenate([S[key].all() for key in S]))
-        raise NotImplementedError("Unable to flatten the given set of DOF's.")
+            return np.unique(np.concatenate([S[key].flatten() for key in S]))
+        raise NotImplementedError("Unable to flatten the given set of DOFs.")
 
 
 def condense(A: spmatrix,
@@ -200,7 +201,15 @@ def condense(A: spmatrix,
              expand: bool = True) -> CondensedSystem:
     """Eliminate degrees-of-freedom from a linear system.
 
-    Supports also generalized eigenvalue problems.
+    The user should provide the linear system ``A`` and ``b``
+    and either the set of DOFs to eliminate (``D``) or the set
+    of DOFs to keep (``I``).  Optionally, nonzero values for
+    the eliminated DOFs can be supplied via ``x``.
+
+    .. note::
+
+        Supports also generalized eigenvalue problems
+        where ``b`` is a matrix.
 
     Parameters
     ----------
@@ -219,13 +228,14 @@ def condense(A: spmatrix,
     expand
         If `True` (default), returns also `x` and `I`. As a consequence,
         :func:`skfem.utils.solve` will expand the solution vector
-        automatically. Otherwise, r
+        automatically.
 
     Returns
     -------
     CondensedSystem
-        The condensed linear system (and optionally information about
-        the boundary values).
+        The condensed linear system and (optionally) information about
+        the boundary values.
+
     """
     D = _flatten_dofs(D)
     I = _flatten_dofs(I)
@@ -275,16 +285,17 @@ def rcm(A: spmatrix,
 def adaptive_theta(est, theta=0.5, max=None):
     """For choosing which elements to refine in an adaptive strategy."""
     if max is None:
-        return np.nonzero(theta*np.max(est) < est)[0]
+        return np.nonzero(theta * np.max(est) < est)[0]
     else:
-        return np.nonzero(theta*max < est)[0]
+        return np.nonzero(theta * max < est)[0]
 
 
 def project(fun,
             basis_from: Basis = None,
             basis_to: Basis = None,
             diff: int = None,
-            I: ndarray = None) -> ndarray:
+            I: ndarray = None,
+            expand: bool = False) -> ndarray:
     """Projection from one basis to another.
 
     Parameters
@@ -299,6 +310,8 @@ def project(fun,
         Differentiate with respect to the given dimension.
     I
         Index set for limiting the projection to a subset.
+    expand
+        Passed to :func:`skfem.utils.condense`.
 
     Returns
     -------
@@ -314,7 +327,13 @@ def project(fun,
 
     @LinearForm
     def funv(v, w):
-        p = fun(*w.x) * v
+        if len(signature(fun).parameters) == 1:
+            p = fun(w.x) * v
+        else:
+            warnings.warn("The function provided to 'project' should "
+                          "take only one argument in the future.",
+                          DeprecationWarning)
+            p = fun(*w.x) * v
         return sum(p) if isinstance(basis_to.elem, ElementVectorH1) else p
 
     @BilinearForm
@@ -334,15 +353,17 @@ def project(fun,
             f = asm(mass, basis_from, basis_to) @ fun
 
     if I is not None:
-        return solve(*condense(M, f, I=I, expand=False))
+        return solve(*condense(M, f, I=I, expand=expand))
 
     return solve(M, f)
 
 
 # for backwards compatibility
 def L2_projection(a, b, c=None):
+    """Superseded by :func:`skfem.utils.project`."""
     return project(a, basis_to=b, I=c)
 
 
 def derivative(a, b, c, d=0):
+    """Superseded by :func:`skfem.utils.project`."""
     return project(a, basis_from=b, basis_to=c, diff=d)
